@@ -1,12 +1,15 @@
 import { DataQuery, DataSourceRef } from '@grafana/schema';
 
-import { User } from './api/types';
+import { User } from './utils/types';
 
-export type QueryTemplateRow = {
-  index: string;
-  datasourceName?: string;
-  description?: string;
+export type QueryTemplate = {
   query: DataQuery;
+  datasourceName?: string;
+  title?: string;
+  description?: string;
+  tags?: string[];
+  isLocked?: boolean;
+  isVisible?: boolean;
   queryText?: string;
   datasourceRef?: DataSourceRef | null;
   datasourceType?: string;
@@ -14,3 +17,7 @@ export type QueryTemplateRow = {
   user?: User;
   uid?: string;
 };
+
+export type QueryTemplateRow = QueryTemplate & {
+  index: string;
+};
